@@ -11,11 +11,10 @@ def remove_app(app_name:str):
 
     project_data=read_project_file()
 
-    if app_name not in project_data["apps"]:
+    if app_name not in project_data["apps"].keys():
         print(f"App {app_name} not found")
     else:
-        project_data["apps"].remove(app_name)
-
+        del project_data["apps"][app_name]
     save_project_file(project_data)
 
 @app.command(name="apps",
@@ -25,9 +24,9 @@ def remove_apps(apps:List[str]):
     project_data=read_project_file()
 
     for app_name in apps:
-        if app_name not in project_data["apps"]:
+        if app_name not in project_data["apps"].keys():
             print(f"App {app_name} not found")
         else:
-            project_data["apps"].remove(app_name)
+            del project_data["apps"][app_name]
     
     save_project_file(project_data)
